/**
 * Copyright 2019 Google LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { GitHub } from './github';
export interface CommitsResponse {
    endCursor?: string;
    hasNextPage: boolean;
    commits: Commit[];
}
export interface Commit {
    sha: string | null;
    message: string;
    files: string[];
}
interface CommitHistoryGraphQLResponse {
    repository: {
        defaultBranchRef: {
            target: {
                history: CommitHistory;
            };
        };
    };
}
interface CommitHistory {
    edges: CommitEdge[];
    pageInfo: PageInfo;
}
interface CommitEdge {
    node: {
        message: string;
        oid: string;
        associatedPullRequests: {
            edges: PREdge[];
        };
    };
}
export interface PREdge {
    node: {
        number: number;
        mergeCommit: {
            oid: string;
        };
        files: {
            edges: FileEdge[];
            pageInfo: PageInfo;
        };
        labels: {
            edges: LabelEdge[];
        };
    };
}
interface FileEdge {
    node: {
        path: string;
    };
}
interface LabelEdge {
    node: {
        name: string;
    };
}
interface PageInfo {
    endCursor: string;
    hasNextPage: boolean;
}
export declare function graphqlToCommits(github: GitHub, response: CommitHistoryGraphQLResponse): Promise<CommitsResponse>;
export {};
