"use strict";
/**
 * Copyright 2019 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const release_pr_1 = require("./release-pr");
const java_auth_yoshi_1 = require("./releasers/java-auth-yoshi");
const node_1 = require("./releasers/node");
const php_yoshi_1 = require("./releasers/php-yoshi");
const ruby_yoshi_1 = require("./releasers/ruby-yoshi");
const java_yoshi_1 = require("./releasers/java-yoshi");
class ReleasePRFactory {
    static build(releaseType, options) {
        const releaseOptions = Object.assign(Object.assign({}, options), { releaseType });
        switch (releaseType) {
            case release_pr_1.ReleaseType.Node:
                return new node_1.Node(releaseOptions);
            case release_pr_1.ReleaseType.PHPYoshi:
                return new php_yoshi_1.PHPYoshi(releaseOptions);
            case release_pr_1.ReleaseType.JavaAuthYoshi:
                // TODO: coerce this to the generic Java release
                return new java_auth_yoshi_1.JavaAuthYoshi(releaseOptions);
            case release_pr_1.ReleaseType.JavaYoshi:
                return new java_yoshi_1.JavaYoshi(releaseOptions);
            case release_pr_1.ReleaseType.RubyYoshi:
                return new ruby_yoshi_1.RubyYoshi(releaseOptions);
            default:
                throw Error('unknown release type');
        }
    }
}
exports.ReleasePRFactory = ReleasePRFactory;
//# sourceMappingURL=release-pr-factory.js.map